@@ -5,6 +5,9 @@ import abc
 import inspect
 import hashlib
 import orjson
+import pathlib
+from pathlib import Path
+
 from typing import Any, AnyStr, Dict, List, Optional, Union
 
 from inflection import underscore, camelize
@@ -30,6 +33,7 @@ from decorator import decorate
 from cytoolz.dicttoolz import keyfilter
 from cachetools import cached, cachedmethod, LRUCache, MRUCache
 from devtools import debug
+from infra_deploy.kube_apply import from_yaml
 # from infra_deploy.models import (
 #     Service,
 # )
@@ -568,10 +572,16 @@ class Composition(ExtraBase, abc.ABC):
                     configs.append(srvs.ambassador_kube())
         self.__response__ = configs
 
-    @abc.abstractmethod
+    # @abc.abstractmethod
     def run(self):
-        raise NotImplementedError
-        # func()
+        from_yaml(self.to_yaml())
+
+    def save_yaml(self, file_name: str, save_dir: Path = Path.cwd()):
+        complete_path = save_dir / file_name
+        with complete_path.open("+w") as f:
+            f.seek(0)
+            f.write(self.to_yaml())
+            f.truncate()
 
 
 class TestInit(KubeBase):
